@@ -1,4 +1,4 @@
-# Copyright 2018 Descartes Labs.
+# Copyright 2018-2019 Descartes Labs.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,8 +16,25 @@
 from descarteslabs.client.services.metadata import Metadata
 from descarteslabs.client.services.places import Places
 from descarteslabs.client.services.raster import Raster
-from descarteslabs.client.services.storage import Storage, cached
+from descarteslabs.client.services.storage import Storage
 from descarteslabs.client.services.catalog import Catalog
-from descarteslabs.client.services.tasks import AsyncTasks, Tasks, FutureTask, CloudFunction
+from descarteslabs.client.services.tasks import (
+    AsyncTasks,
+    Tasks,
+    FutureTask,
+    CloudFunction,
+)
+from descarteslabs.client.services.vector import Vector
 
-__all__ = ["Raster", "Metadata", "Places", "Storage", "Catalog", "AsyncTasks", "Tasks", "FutureTask", "CloudFunction"]
+__all__ = [
+    "Raster",
+    "Metadata",
+    "Places",
+    "Storage",
+    "Catalog",
+    "AsyncTasks",
+    "Tasks",
+    "FutureTask",
+    "CloudFunction",
+    "Vector",
+]
