@@ -1,4 +1,4 @@
-# Copyright 2018 Descartes Labs.
+# Copyright 2018-2019 Descartes Labs.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,8 +13,9 @@
 # limitations under the License.
 
 from .metadata import Metadata
-from .metadata_filtering import GLOBAL_PROPERTIES
+from descarteslabs.common.property_filtering import GenericProperties
 
-properties = GLOBAL_PROPERTIES
+
+properties = GenericProperties()
 
 __all__ = ["Metadata", "properties"]
