@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright 2018 Descartes Labs.
+# Copyright 2018-2019 Descartes Labs.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,34 +15,35 @@
 
 import argparse
 import json
+
+import six
+
 from .raster import Raster
 
 
 def scales(s):
     if s.count(",") == 1:
-        mi, ma = map(float, s.split(","))
+        mi, ma = six.moves.map(float, s.split(","))
         return [mi, ma]
     elif s.count(",") == 3:
-        smi, sma, dmi, dma = map(float, s.split(","))
+        smi, sma, dmi, dma = six.moves.map(float, s.split(","))
         return [smi, sma, dmi, dma]
     else:
-        raise argparse.ArgumentTypeError(
-            "Scales must be mi,ma or smi,sma,dmi,dma"
-        )
+        raise argparse.ArgumentTypeError("Scales must be mi,ma or smi,sma,dmi,dma")
 
 
 def raster_handler(args):
     params = {
-        'inputs': args.inputs,
-        'bands': args.bands,
-        'scales': args.scales,
-        'resolution': args.resolution,
-        'data_type': args.data_type,
-        'output_format': args.output_format,
-        'srs': args.srs,
-        'place': args.place,
-        'save': True,
-        'outfile_basename': args.outfile_basename,
+        "inputs": args.inputs,
+        "bands": args.bands,
+        "scales": args.scales,
+        "resolution": args.resolution,
+        "data_type": args.data_type,
+        "output_format": args.output_format,
+        "srs": args.srs,
+        "place": args.place,
+        "save": True,
+        "outfile_basename": args.outfile_basename,
     }
     response = Raster().raster(**params)
-    print(json.dumps(response['metadata'], indent=2))
+    print(json.dumps(response["metadata"], indent=2))
